YALP
====

|build-status| |coverage| |deps| |pypi| |docs|

Distributed log parsing and collection.

.. |build-status| image:: http://img.shields.io/travis/yalp-log/yalp/master.svg?style=flat
    :alt: Build Status
    :scale: 100%
    :target: https://travis-ci.org/yalp-log/yalp

.. |coverage| image:: http://img.shields.io/coveralls/yalp-log/yalp.svg?style=flat
    :alt: Coverage Status
    :scale: 100%
    :target: https://coveralls.io/r/yalp-log/yalp?branch=master

.. |deps| image:: http://img.shields.io/gemnasium/yalp-log/yalp.svg?style=flat
    :alt: Dependency Status
    :scale: 100%
    :target: https://gemnasium.com/yalp-log/yalp

.. |pypi| image:: http://img.shields.io/pypi/v/yalp.svg?style=flat
    :alt: PyPi version
    :scale: 100%
    :target: https://pypi.python.org/pypi/yalp

.. |docs| image:: https://readthedocs.org/projects/yalp/badge/
    :alt: Documentation Status
    :scale: 100%
    :target: https://yalp.readthedocs.org
